# SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
# SPDX-License-Identifier: BSD-3-Clause
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


# Path to the optional display driver variant override file.
# Write the desired variant name (e.g. "nvgpu-l4t" or "openrm-l4t") into
# this file to override automatic chip detection.
NV_LOAD_DISPLAY_MODULES_VARIANT_OVERRIDE="/etc/nvidia-gpu-driver-override"

# Choose display variant. If NV_LOAD_DISPLAY_MODULES_VARIANT_OVERRIDE is
# present and non-empty, its value is used as the variant name. Otherwise:
# tegra23x chips use nvgpu-l4t; tegra264 and later use openrm-l4t.
nv_load_display_modules_choose_variant() {
	if [ -f "${NV_LOAD_DISPLAY_MODULES_VARIANT_OVERRIDE}" ]; then
		local _variant
		_variant="$(tr -d '\n' \
			< "${NV_LOAD_DISPLAY_MODULES_VARIANT_OVERRIDE}" 2>/dev/null)"
		_variant="${_variant,,}"
		if [ -n "${_variant}" ]; then
			echo "Display variant override: ${_variant}." >&2
			echo "${_variant}"
			return
		fi
	fi
	local chip
	chip="$(tr -d '\0' < /proc/device-tree/compatible 2>/dev/null)" || true
	if [[ "${chip}" =~ "tegra23" ]]; then
		echo "nvgpu-l4t"
	else
		# tegra264 and later use openrm-l4t
		echo "openrm-l4t"
	fi
}
